@@ -10,7 +10,7 @@ HTML::GoogleMaps::V3 - a simple wrapper around the Google Maps API
 
 =head1 VERSION
 
-0.08
+0.09
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ use warnings;
 use Geo::Coder::Google;
 use Template;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub new {
     my ( $class,%opts ) = @_;
@@ -85,7 +85,7 @@ sub new {
         poly_lines => [],
         geocoder   => Geo::Coder::Google->new(
             apidriver => 3,
-            ( $opts{'api_key'} ? ( key => $opts{'api_key'} ) : () ),
+            ( $opts{'api_key'} ? ( key => $opts{'api_key'}, sensor => 'false' ) : () ),
         ),
     }, $class );
 }
